==> nextcloud-app-tasks-0.15.0-1-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/tasks/l10n/zh_CN.js <==
OC.L10N.register(
    "tasks",
    {
    "Upcoming tasks" : "即将到来的任务",
    "Important" : "重要",
    "Today" : "今天",
    "Week" : "星期",
    "All" : "全部",
    "Current" : "当前",
    "Completed" : "完成",
    "Tasks" : "任务",
    "The Tasks app for Nextcloud" : "Nextcloud 任务应用",
    "Default list" : "默认列表",
    "Visibility of Smart Collections" : "智能集合的可见性",
    "Hidden" : "隐藏",
    "Visible" : "可见",
    "Automatic" : "自动",
    "Share with users or groups" : "和用户或者群组共享",
    "No users or groups" : "无用户或群组",
    "Can edit" : "可以编辑",
    "Unshare with {displayName}" : "取消与{displayName}的共享",
    "Unable to delete the share." : "无法删除此共享。",
    "Unable to change permissions." : "无法修改权限。",
    "Edit" : "编辑",
    "Copy private link" : "复制私人链接",
    "Copied" : "已复制",
    "Cannot copy" : "无法复制 ",
    "Export" : "导出",
    "Delete" : "删除",
    "Unshare" : "取消共享",
    "List name" : "列表名称",
    "This will delete the calendar \"{calendar}\" and all corresponding events and tasks." : "此操作将删除日历\"{calendar}\"以及所有相应的事件和任务。",
    "This will unshare the calendar \"{calendar}\"." : "这将取消共享日历“{calendar}”。",
    "This will delete the list \"{list}\" and all corresponding tasks." : "这会删除列表 \"{list}\" 和所有相应的任务。",
    "This will unshare the list \"{list}\"." : "这会取消共享列表 \"{list}\"。",
    "Calendar link copied to clipboard." : "日历链接已复制到剪贴板。",
    "List link copied to clipboard." : "列表链接已复制到剪贴板",
    "Calendar link could not be copied to clipboard." : "日历链接无法复制到剪贴板。",
    "List link could not be copied to clipboard." : "列表连接无法被复制到剪贴板",
    "The name \"{calendar}\" is already used." : "名称 \"{calendar}\" 已被使用。",
    "An empty name is not allowed." : "不允许使用空名称。",
    "An error occurred, unable to delete the calendar." : "发生错误，无法删除日历。",
    "An error occurred, unable to delete the list." : "发生错误，无法删除列表",
    "_Deleting the calendar in {countdown} second_::_Deleting the calendar in {countdown} seconds_" : ["将在 {countdown} 秒后删除这个日历"],
    "_Unsharing the calendar in {countdown} second_::_Unsharing the calendar in {countdown} seconds_" : ["将在 {countdown} 秒后取消共享这个日历"],
    "_Deleting the list in {countdown} second_::_Deleting the list in {countdown} seconds_" : ["将在  {countdown} 秒后删除列表"],
    "_Unsharing the list in {countdown} second_::_Unsharing the list in {countdown} seconds_" : ["将在  {countdown} 后取消共享这个列表"],
    "_Shared with {num} entity_::_Shared with {num} entities_" : ["与 {num} 个实体共享"],
    "Trash bin" : "垃圾箱",
    "Loading deleted calendars, tasks and events." : "正在加载已删除的日历、任务和事件",
    "You do not have any deleted calendars, tasks or events." : "您没有任何已删除的日历、任务或事件。",
    "Name" : "名称",
    "Deleted" : "已删除",
    "Restore" : "还原",
    "Delete permanently" : "永久删除",
    "Empty trash bin" : "清空回收站",
    "Untitled task" : "无标题任务",
    "Untitled event" : "无标题事件",
    "Untitled journal" : "无标题日记",
    "Untitled item" : "未命名项",
    "Unknown calendar" : "未知日历",
    "Could not load deleted calendars and objects" : "无法加载已删除的日历和对象",
    "Could not delete calendar or event" : "无法删除日历或事件",
    "Could not restore calendar or event" : "无法还原日历或事件",
    "Do you really want to empty the trash bin?" : "你真想清空回收站吗？",
    "_Elements in the trash bin are deleted after {numDays} day_::_Elements in the trash bin are deleted after {numDays} days_" : ["将于 {numDays} 后删除回收站内元素"],
    "Select a calendar" : "选择一个日历",
    "No calendar matches the search." : "没有同搜索相匹配的日历",
    "Set date" : "设置日期",
    "Set time" : "设置时间",
    "Delete date" : "删除日期",
    "Click here to add a note." : "点击此处添加一条附注",
    "Set value" : "设置值",
    "Delete value" : "删除值",
    "Add this as a new tag" : "将此添加为一个新标签",
    "No tag available. Create one!" : "无标签可用。新建一个！",
    "Delete all completed tasks." : "删除所有已完成任务。",
    "Delete completed tasks." : "删除已完成任务。",
    "Deleted all completed tasks from calendar \"{calendar}\"." : "从日历 \"{calendar}\" 中删除所有已完成任务。",
    "No errors" : "没有错误",
    "Open your browser console for more details" : "打开您的浏览器控制台以获取更多详细信息",
    "_This will delete {taskCount} completed task and its subtasks from calendar \"{calendar}\"._::_This will delete {taskCount} completed tasks and their subtasks from calendar \"{calendar}\"._" : ["此操作将从日历 \"{calendar}\" 中删除 {taskCount} 个已完成任务及其子任务。"],
    "_Could not delete {failedCount} task._::_Could not delete {failedCount} tasks._" : ["无法删除 {failedCount} 个任务。"],
    "Add an important task to \"{calendar}\"…" : "添加重要任务到 \"{calendar}\" ...",
    "Add a task due today to \"{calendar}\"…" : "添加今天截止的任务到 \"{calendar}\" ...",
    "Add a current task to \"{calendar}\"…" : "添加当前任务到 \"{calendar}\" ...",
    "Add a task to \"{calendar}\"…" : "添加任务到 \"{calendar}\" ...",
    "Change sort order" : "更改排序",
    "Relevance" : "相关联",
    "Sort by completed state, due date, priority, start date and summary." : "按已完成状态，截止日期，优先级，开始日期及概况排序",
    "Start date" : "开始日期",
    "Due date" : "截止日期",
    "Created date" : "创建日期",
    "Last modified" : "上一次更改",
    "Completed date" : "完成日期",
    "Priority" : "优先级",
    "Sort by priority and summary." : "按优先级和摘要排序。",
    "Alphabetically" : "按字母顺序",
    "Sort by summary and priority." : "按摘要和优先级排序。",
    "Manually" : "手动",
    "Sort by manual order." : "按手动顺序排序。",
    "{complete} % completed" : "{complete} % 已完成",
    "Task has hidden subtasks" : "任务有隐藏的子任务",
    "Task is pinned" : "已固定任务",
    "Task has a note" : "任务有一条附注",
    "Add subtask" : "添加子任务",
    "Show subtasks" : "显示子任务",
    "Hide subtasks" : "隐藏子任务",
    "Show closed subtasks" : "显示关闭的子任务",
    "Hide closed subtasks" : "隐藏关闭的子任务",
    "Delete task" : "删除任务",
    "Toggle starred" : "加星标/取消星标",
    "[Yesterday]" : "[昨天]",
    "[Today]" : "[今天]",
    "[Tomorrow]" : "[明天]",
    "[Completed yesterday]" : "[昨天完成]",
    "[Completed today]" : "[今天完成]",
    "[Completed tomorrow]" : "[明天完成]",
    "[Yesterday at] LT" : "[于昨天的] LT",
    "[Today at] LT" : "[于今天的] LT",
    "[Tomorrow at] LT" : "[于明天的] LT",
    "L [at] LT" : "L [于] LT",
    "[Completed yesterday at] LT" : "[已完成于昨天的] LT",
    "[Completed today at] LT" : "[已完成于今天的] LT",
    "[Completed tomorrow at] LT" : "[已完成于明天的] LT",
    "[Completed] L [at] LT" : "[已完成] L [于] LT",
    "Add a subtask to \"{task}\"…" : "添加子任务到 \"{task}\" ...",
    "_Deleting the task in {countdown} second_::_Deleting the task in {countdown} seconds_" : ["在 {countdown} 秒后删除任务"],
    "Task is completed" : "任务完成",
    "Create a new task" : "创建一个新任务",
    "Task summary" : "任务概要",
    "Cancel" : "取消",
    "Create task" : "创建任务",
    "Creating the new task…" : "正在创建新任务…",
    "Close" : "关闭",
    "Open task" : "打开任务",
    "\"{task}\" was added to \"{calendar}\"" : "\"{task}\" 已被添加至  \"{calendar}\"",
    "_%n Completed Task_::_%n Completed Tasks_" : ["%n 任务完成"],
    "Tomorrow" : "明天",
    "Add List…" : "添加列表 ...",
    "All day" : "所有天",
    "Unpin" : "取消固定",
    "Pin" : "固定",
    "Show in Calendar" : "在日历中显示",
    "Edit title" : "编辑标题",
    "Details" : "详情",
    "Select a classification" : "选择类别",
    "Select a status" : "选择一个状态",
    "Select tags" : "选择标签",
    "Notes" : "辅组",
    "Reminders" : "提醒",
    "Repeat" : "重复",
    "When shared show full event" : "共享时显示完整事件",
    "When shared show only busy" : "共享时仅显示进行中的事件",
    "When shared hide this event" : "共享时隐藏本事件",
    "Needs action" : "需要操作",
    "In process" : "处理中",
    "Canceled" : "已取消",
    "Clear status" : "清除日期",
    "Loading task from server." : "从服务器加载任务。",
    "Task not found!" : "没有任务！",
    "[Starts today]" : "[今天开始]",
    "[Starts tomorrow]" : "[明天开始]",
    "[Starts on] LL" : "[开始于] LL",
    "[Started yesterday]" : "[已开始于昨天]",
    "[Started on] LL" : "[已开始于] LL",
    "[Started today at] LT" : "[已开始于今天的] LT",
    "[Starts today at] LT" : "[开始于今天的] LT",
    "[Starts tomorrow at] LT" : "[开始于明天的] LT",
    "[Starts on] LL [at] LT" : "[开始于] LL [的] LT",
    "[Started yesterday at] LT" : "[已开始于昨天的] LT",
    "[Started on] LL [at] LT" : "[已开始于] LL [的] LT",
    "Set start date" : "设置开始日期",
    "[Due today]" : "[今天截止]",
    "[Due tomorrow]" : "[明天截止]",
    "[Due on] LL" : "[截止于] LL",
    "[Was due yesterday]" : "[已于昨天截止]",
    "[Was due on] LL" : "[已截止于] LL",
    "[Was due today at] LT" : "[已截止于今天的] LT",
    "[Due today at] LT" : "[截止于今天的] LT",
    "[Due tomorrow at] LT" : "[截止于明天的] LT",
    "[Due on] LL [at] LT" : "[截止于] LL [的] LT",
    "[Was due yesterday at] LT" : "[已截止于昨天的] LT",
    "[Was due on] LL [at] LT" : "[已截止于] LL [的] LT",
    "Set due date" : "设置截止日期",
    "Priority {priority}: low" : "优先级 {priority}：低",
    "Priority {priority}: medium" : "优先级 {priority}：中",
    "Priority {priority}: high" : "优先级 {priority}：高",
    "No priority assigned" : "未设置优先级",
    "{percent} % completed" : "{percent} % 已完成",
    "No upcoming tasks" : "没有即将到来的任务",
    "upcoming tasks" : "即将到来的任务",
    "No tasks today" : "今天没有任务",
    "Mark as done" : "标记为已完成",
    "No due date assigned" : "未分配到期日",
    "Successfully created the task." : "成功创建任务。",
    "Could not delete the task." : "无法删除任务。",
    "Synchronizing to the server." : "正在同步到服务器。",
    "Task successfully saved to server." : "任务已成功保存到服务器。",
    "Could not update the task because it was changed on the server. Please click to refresh it, local changes will be discarded." : "无法更新任务，因为它已在服务器上被更改。请点击以刷新此任务，本地变更将被丢弃。",
    "Could not update the task." : "无法更新任务。",
    "Successfully updated the task." : "成功更新任务。",
    "Task successfully moved to new calendar." : "任务已成功移至新日历。",
    "An error occurred" : "发生了一个错误",
    "Create a task" : "创建一个任务",
    "Message from {author} in {conversationName}" : "{conversationName} 中来自 {author} 的消息"
},
"nplurals=1; plural=0;");

==> nextcloud-app-tasks-0.16.1-1.0-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/tasks/l10n/zh_CN.js <==
OC.L10N.register(
    "tasks",
    {
    "Upcoming tasks" : "即将到来的任务",
    "Important" : "重要",
    "Today" : "今天",
    "Week" : "星期",
    "All" : "全部",
    "Current" : "当前",
    "Completed" : "完成",
    "Tasks" : "任务",
    "The Tasks app for Nextcloud" : "Nextcloud 任务应用",
    "Once enabled, a new Tasks menu will appear in your Nextcloud apps menu. From there you can add and delete tasks, edit their title, description, start and due dates and mark them as important. Tasks can be shared between users. Tasks can be synchronized using CalDav (each task list is linked to an Nextcloud calendar, to sync it to your local client: Thunderbird, Evolution, KDE Kontact, iCal … - just add the calendar as a remote calendar in your client). You can download your tasks as ICS files using the download button for each calendar." : "启用后，新的任务菜单将出现在您的 Nextcloud 应用程序菜单中。 从那里您可以添加和删除任务，编辑其标题、描述、开始日期和截止日期并将其标记为重要。 任务可以在用户之间共享。 可以使用 CalDav 同步任务（每个任务列表都链接到 Nextcloud 日历，以将其同步到本地客户端：Thunderbird、Evolution、KDE Kontact、iCal ... - 只需将日历添加为客户端中的远程日历）。 您可以使用每个日历的下载按钮将任务下载为 ICS 文件。",
    "Default list" : "默认列表",
    "Visibility of Smart Collections" : "智能集合的可见性",
    "Hidden" : "隐藏",
    "Visible" : "可见",
    "Automatic" : "自动",
    "Tasks settings" : "设置",
    "Share with users or groups" : "和用户或者群组共享",
    "No users or groups" : "无用户或群组",
    "Can edit" : "可以编辑",
    "Unshare with {displayName}" : "取消与{displayName}的共享",
    "Unable to delete the share." : "无法删除此共享。",
    "Unable to change permissions." : "无法修改权限。",
    "Edit" : "编辑",
    "Copy private link" : "复制私人链接",
    "Copied" : "已复制",
    "Cannot copy" : "无法复制 ",
    "Export" : "导出",
    "Delete" : "删除",
    "Unshare" : "取消共享",
    "List name" : "列表名称",
    "This will delete the calendar \"{calendar}\" and all corresponding events and tasks." : "此操作将删除日历\"{calendar}\"以及所有相应的事件和任务。",
    "This will unshare the calendar \"{calendar}\"." : "这将取消共享日历“{calendar}”。",
    "This will delete the list \"{list}\" and all corresponding tasks." : "这会删除列表 \"{list}\" 和所有相应的任务。",
    "This will unshare the list \"{list}\"." : "这会取消共享列表 \"{list}\"。",
    "Share this calendar" : "分享此日历",
    "Share this list" : "分享此列表",
    "Calendar link copied to clipboard." : "日历链接已复制到剪贴板。",
    "List link copied to clipboard." : "列表链接已复制到剪贴板",
    "Calendar link could not be copied to clipboard." : "日历链接无法复制到剪贴板。",
    "List link could not be copied to clipboard." : "列表连接无法被复制到剪贴板",
    "The name \"{calendar}\" is already used." : "名称 \"{calendar}\" 已被使用。",
    "An empty name is not allowed." : "不允许使用空名称。",
    "An error occurred, unable to delete the calendar." : "发生错误，无法删除日历。",
    "An error occurred, unable to delete the list." : "发生错误，无法删除列表",
    "_Deleting the calendar in {countdown} second_::_Deleting the calendar in {countdown} seconds_" : ["将在{countdown}秒后删除这个日历"],
    "_Unsharing the calendar in {countdown} second_::_Unsharing the calendar in {countdown} seconds_" : ["将在{countdown}秒后取消共享这个日历"],
    "_Deleting the list in {countdown} second_::_Deleting the list in {countdown} seconds_" : ["将在{countdown}秒后删除列表"],
    "_Unsharing the list in {countdown} second_::_Unsharing the list in {countdown} seconds_" : ["将在{countdown}秒后取消共享这个列表"],
    "_Shared with {num} entity_::_Shared with {num} entities_" : ["与 {num} 个实体共享"],
    "Trash bin" : "垃圾箱",
    "Loading deleted calendars, tasks and events." : "正在加载已删除的日历、任务和事件",
    "You do not have any deleted calendars, tasks or events." : "您没有任何已删除的日历、任务或事件。",
    "Name" : "名称",
    "Deleted" : "已删除",
    "Restore" : "还原",
    "Delete permanently" : "永久删除",
    "Empty trash bin" : "清空回收站",
    "Untitled task" : "无标题任务",
    "Untitled event" : "无标题事件",
    "Untitled journal" : "无标题日记",
    "Untitled item" : "未命名项",
    "Unknown calendar" : "未知日历",
    "Could not load deleted calendars and objects" : "无法加载已删除的日历和对象",
    "Could not delete calendar or event" : "无法删除日历或事件",
    "Could not restore calendar or event" : "无法还原日历或事件",
    "Do you really want to empty the trash bin?" : "你真想清空回收站吗？",
    "_Elements in the trash bin are deleted after {numDays} day_::_Elements in the trash bin are deleted after {numDays} days_" : ["将于 {numDays} 后删除回收站内元素"],
    "Select a calendar" : "选择一个日历",
    "No calendar matches the search." : "没有同搜索相匹配的日历",
    "Set date" : "设置日期",
    "Set time" : "设置时间",
    "Delete date" : "删除日期",
    "Click here to add a note." : "点击此处添加一条附注",
    "Set value" : "设置值",
    "Delete value" : "删除值",
    "Add this as a new tag" : "将此添加为一个新标签",
    "No tag available. Create one!" : "无标签可用。新建一个！",
    "Create new tasks" : "创建新任务",
    "Create {numberOfTasks} tasks from pasted text" : "从粘贴的文本创建 {numberOfTasks} 任务",
    "Cancel" : "取消",
    "Create tasks" : "创建任务",
    "Creating new tasks…" : "创建新任务...",
    "Close" : "关闭",
    "{numberOfTasks} tasks have been added to \"{calendar}\"" : "{numberOfTasks} 任务已添加到 \"{calendar}\"",
    "Delete all completed tasks." : "删除所有已完成任务。",
    "Delete completed tasks." : "删除已完成任务。",
    "Deleted all completed tasks from calendar \"{calendar}\"." : "从日历 \"{calendar}\" 中删除所有已完成任务。",
    "No errors" : "没有错误",
    "Open your browser console for more details" : "打开您的浏览器控制台以获取更多详细信息",
    "_This will delete {taskCount} completed task and its subtasks from calendar \"{calendar}\"._::_This will delete {taskCount} completed tasks and their subtasks from calendar \"{calendar}\"._" : ["此操作将从日历 \"{calendar}\" 中删除 {taskCount} 个已完成任务及其子任务。"],
    "_Could not delete {failedCount} task._::_Could not delete {failedCount} tasks._" : ["无法删除 {failedCount} 个任务。"],
    "Active filter" : "有源滤波器",
    "Filter by tags" : "按标签过滤",
    "Select tags to filter by" : "选择标签来筛选",
    "Reset filter" : "重置过滤器",
    "Add an important task to \"{calendar}\"…" : "添加重要任务到 \"{calendar}\" ...",
    "Add a task due today to \"{calendar}\"…" : "添加今天截止的任务到 \"{calendar}\" ...",
    "Add a current task to \"{calendar}\"…" : "添加当前任务到 \"{calendar}\" ...",
    "Add a task to \"{calendar}\"…" : "添加任务到 \"{calendar}\" ...",
    "Load the completed tasks of all lists." : "加载所有列表的已完成任务。",
    "Loading the completed tasks of all lists might slow down the app." : "加载所有列表的已完成任务可能会减慢应用程序的速度。",
    "Load the completed tasks of list \"{calendar}\"." : "加载列表 \"{calendar}\" 的已完成任务。",
    "Loading the completed tasks might slow down the app." : "加载已完成的任务可能会减慢应用程序的速度。",
    "Change sort order" : "更改排序",
    "Relevance" : "相关联",
    "Sort by completed state, due date, priority, start date and summary." : "按已完成状态，截止日期，优先级，开始日期及概况排序",
    "Start date" : "开始日期",
    "Sort by start date, priority and summary." : "按开始日期、优先级和摘要排序。",
    "Due date" : "截止日期",
    "Sort by due date, priority and summary." : "按截止日期、优先级和摘要排序。",
    "Created date" : "创建日期",
    "Sort by created date, priority and summary." : "按创建日期、优先级和摘要排序。",
    "Last modified" : "上一次更改",
    "Sort by last-modified date, priority and summary." : "按上次修改日期、优先级和摘要排序。",
    "Completed date" : "完成日期",
    "Sort by completed date, priority and summary." : "按完成日期、优先级和摘要排序。",
    "Priority" : "优先级",
    "Sort by priority and summary." : "按优先级和摘要排序。",
    "Alphabetically" : "按字母顺序",
    "Sort by summary and priority." : "按摘要和优先级排序。",
    "Manually" : "手动",
    "Sort by manual order." : "按手动顺序排序。",
    "Task has hidden subtasks" : "任务有隐藏的子任务",
    "Task is pinned" : "已固定任务",
    "Task has a note" : "任务有一条附注",
    "{complete} % completed" : "{complete} % 已完成",
    "Add subtask" : "添加子任务",
    "Show subtasks" : "显示子任务",
    "Hide subtasks" : "隐藏子任务",
    "Show closed subtasks" : "显示关闭的子任务",
    "Hide closed subtasks" : "隐藏关闭的子任务",
    "Delete task" : "删除任务",
    "Toggle starred" : "加星标/取消星标",
    "[Yesterday]" : "[昨天]",
    "[Today]" : "[今天]",
    "[Tomorrow]" : "[明天]",
    "[Completed yesterday]" : "[昨天完成]",
    "[Completed today]" : "[今天完成]",
    "[Completed tomorrow]" : "[明天完成]",
    "[Yesterday at] LT" : "[于昨天的] LT",
    "[Today at] LT" : "[于今天的] LT",
    "[Tomorrow at] LT" : "[于明天的] LT",
    "L [at] LT" : "L [于] LT",
    "[Completed yesterday at] LT" : "[已完成于昨天的] LT",
    "[Completed today at] LT" : "[已完成于今天的] LT",
    "[Completed tomorrow at] LT" : "[已完成于明天的] LT",
    "[Completed] L [at] LT" : "[已完成] L [于] LT",
    "Add a subtask to \"{task}\"…" : "添加子任务到 \"{task}\" ...",
    "_Deleting the task in {countdown} second_::_Deleting the task in {countdown} seconds_" : ["将在{countdown}秒后删除任务"],
    "Task is cancelled" : "任务被取消",
    "Task is completed" : "任务完成",
    "Task is read-only" : "任务是只读的",
    "Task is not completed" : "任务未完成",
    "Create a new task" : "创建一个新任务",
    "Task summary" : "任务概要",
    "Create task" : "创建任务",
    "Creating the new task…" : "正在创建新任务…",
    "Open task" : "打开任务",
    "\"{task}\" was added to \"{calendar}\"" : "\"{task}\" 已被添加至  \"{calendar}\"",
    "_%n Completed Task_::_%n Completed Tasks_" : ["%n 任务完成"],
    "Tomorrow" : "明天",
    "Add List…" : "添加列表 ...",
    "New list" : "新列表",
    "All day" : "所有天",
    "Unpin" : "取消固定",
    "Pin" : "固定",
    "Show in Calendar" : "在日历中显示",
    "Show in Deck" : "显示在 Deck 上",
    "Edit summary" : "编辑摘要",
    "Details" : "详情",
    "Selecting a classification is forbidden, because the task was shared with you." : "禁止选择分类，因为该任务已与您共享。",
    "Select a classification" : "选择类别",
    "Select a status" : "选择一个状态",
    "Set a location" : "设置位置",
    "Set a URL" : "设置 URL",
    "Select tags" : "选择标签",
    "Notes" : "附注",
    "Reminders" : "提醒",
    "Repeat" : "重复",
    "When shared show full event" : "共享时显示完整事件",
    "When shared show only busy" : "共享时仅显示进行中的事件",
    "When shared hide this event" : "共享时隐藏本事件",
    "Needs action" : "需要操作",
    "In process" : "处理中",
    "Canceled" : "已取消",
    "Clear status" : "清除日期",
    "Loading task from server." : "从服务器加载任务。",
    "Task not found!" : "没有任务！",
    "Set start date" : "设置开始日期",
    "Set due date" : "设置截止日期",
    "Priority {priority}: low" : "优先级 {priority}：低",
    "Priority {priority}: medium" : "优先级 {priority}：中",
    "Priority {priority}: high" : "优先级 {priority}：高",
    "No priority assigned" : "未设置优先级",
    "{percent} % completed" : "{percent} % 已完成",
    "No upcoming tasks" : "没有即将到来的任务",
    "upcoming tasks" : "即将到来的任务",
    "No tasks today" : "今天没有任务",
    "Mark as done" : "标记为已完成",
    "No due date assigned" : "未分配到期日",
    "[Due today]" : "[今天截止]",
    "[Due tomorrow]" : "[明天截止]",
    "[Due today at] LT" : "[截止于今天的] LT",
    "[Due tomorrow at] LT" : "[截止于明天的] LT",
    "Successfully created the task." : "成功创建任务。",
    "Could not delete the task." : "无法删除任务。",
    "Synchronizing to the server." : "正在同步到服务器。",
    "Task successfully saved to server." : "任务已成功保存到服务器。",
    "Could not update the task because it was changed on the server. Please click to refresh it, local changes will be discarded." : "无法更新任务，因为它已在服务器上被更改。请点击以刷新此任务，本地变更将被丢弃。",
    "Could not update the task." : "无法更新任务。",
    "Successfully updated the task." : "成功更新任务。",
    "Task successfully moved to new calendar." : "任务已成功移至新日历。",
    "An error occurred" : "发生了一个错误",
    "Create a task" : "创建一个任务",
    "Message from {author} in {conversationName}" : "{conversationName} 中来自 {author} 的消息",
    "[Due on] LL" : "[截止于] LL",
    "[Was due yesterday]" : "[已于昨天截止]",
    "[Was due on] LL" : "[已截止于] LL",
    "[Was due today at] LT" : "[已截止于今天的] LT",
    "[Due on] LL [at] LT" : "[截止于] LL [的] LT",
    "[Was due yesterday at] LT" : "[已截止于昨天的] LT",
    "[Was due on] LL [at] LT" : "[已截止于] LL [的] LT",
    "[Starts today]" : "[今天开始]",
    "[Starts tomorrow]" : "[明天开始]",
    "[Starts on] LL" : "[开始于] LL",
    "[Started yesterday]" : "[已开始于昨天]",
    "[Started on] LL" : "[已开始于] LL",
    "[Started today at] LT" : "[已开始于今天的] LT",
    "[Starts today at] LT" : "[开始于今天的] LT",
    "[Starts tomorrow at] LT" : "[开始于明天的] LT",
    "[Starts on] LL [at] LT" : "[开始于] LL [的] LT",
    "[Started yesterday at] LT" : "[已开始于昨天的] LT",
    "[Started on] LL [at] LT" : "[已开始于] LL [的] LT"
},
"nplurals=1; plural=0;");
